@@ -30,9 +30,8 @@
 #define ARCHIVEINTERFACE_H
 
 #include "archive_kerfuffle.h"
-#include "archive_entry.h"
 #include "kerfuffle_export.h"
-#include "kerfuffle/archiveentry.h"
+#include "archiveentry.h"
 
 #include <QObject>
 #include <QStringList>
@@ -48,7 +47,7 @@ class KERFUFFLE_EXPORT ReadOnlyArchiveInterface: public QObject
     Q_OBJECT
 public:
     explicit ReadOnlyArchiveInterface(QObject *parent, const QVariantList &args);
-    virtual ~ReadOnlyArchiveInterface();
+    ~ReadOnlyArchiveInterface() override;
 
     /**
      * Returns the filename of the archive currently being handled.
@@ -156,7 +155,7 @@ public:
     bool isHeaderEncryptionEnabled() const;
     virtual QString multiVolumeName() const;
     void setMultiVolume(bool value);
-    int numberOfEntries() const;
+    uint numberOfEntries() const;
     QMimeType mimetype() const;
 
     /**
@@ -192,7 +191,7 @@ protected:
     bool isCorrupt() const;
     QString m_comment;
     int m_numberOfVolumes;
-    int m_numberOfEntries;
+    uint m_numberOfEntries;
     KPluginMetaData m_metaData;
 
 private:
@@ -217,9 +216,9 @@ public:
     };
 
     explicit ReadWriteArchiveInterface(QObject *parent, const QVariantList &args);
-    virtual ~ReadWriteArchiveInterface();
+    ~ReadWriteArchiveInterface() override;
 
-    bool isReadOnly() const Q_DECL_OVERRIDE;
+    bool isReadOnly() const override;
 
     virtual bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions& options, uint numberOfEntriesToAdd = 0) = 0;
     virtual bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions& options) = 0;
